export interface ITimeZoneRepresentation {
    zoneHours: number;
    zoneMinutes: number;
}
export interface IDateRepresentation extends Partial<ITimeZoneRepresentation> {
    year: number;
    month: number;
    day: number;
}
export interface ITimeRepresentation extends Partial<ITimeZoneRepresentation> {
    hours: number;
    minutes: number;
    seconds: number;
}
export interface IDayTimeDurationRepresentation {
    hours: number;
    minutes: number;
    seconds: number;
    day: number;
}
export interface IYearMonthDurationRepresentation {
    year: number;
    month: number;
}
export declare type IDurationRepresentation = IYearMonthDurationRepresentation & IDayTimeDurationRepresentation;
export declare type IDateTimeRepresentation = IDateRepresentation & ITimeRepresentation;
export declare function defaultedDayTimeDurationRepresentation(rep: Partial<IDayTimeDurationRepresentation>): IDayTimeDurationRepresentation;
export declare function defaultedYearMonthDurationRepresentation(rep: Partial<IYearMonthDurationRepresentation>): IYearMonthDurationRepresentation;
export declare function defaultedDurationRepresentation(rep: Partial<IDurationRepresentation>): IDurationRepresentation;
export declare function simplifyDurationRepresentation(rep: Partial<IDurationRepresentation>): Partial<IDurationRepresentation>;
export declare function defaultedDateTimeRepresentation(rep: Partial<IDateTimeRepresentation>): IDateTimeRepresentation;
export declare function toDateTimeRepresentation({ date, timeZone }: {
    date: Date;
    timeZone: ITimeZoneRepresentation;
}): IDateTimeRepresentation;
export declare function negateDuration(dur: Partial<IDurationRepresentation>): Partial<IDurationRepresentation>;
export declare function toJSDate(date: IDateTimeRepresentation): Date;
export declare function toUTCDate(date: Partial<IDateTimeRepresentation>, defaultTimezone: ITimeZoneRepresentation): Date;
export declare function trimToYearMonthDuration(dur: Partial<IDurationRepresentation>): Partial<IYearMonthDurationRepresentation>;
export declare function trimToDayTimeDuration(dur: Partial<IDurationRepresentation>): Partial<IDayTimeDurationRepresentation>;
export declare function yearMonthDurationsToMonths(dur: IYearMonthDurationRepresentation): number;
export declare function dayTimeDurationsToSeconds(dur: IDayTimeDurationRepresentation): number;
export declare function extractRawTimeZone(zoneContained: string): string;
export declare function extractTimeZone(date: Date): ITimeZoneRepresentation;
